aboutsummaryrefslogtreecommitdiffstats
path: root/src/arch/x86/include
diff options
context:
space:
mode:
authorMichael Brown <mcb30@ipxe.org>2011-02-12 02:08:28 +0000
committerMichael Brown <mcb30@ipxe.org>2011-02-17 01:25:11 +0000
commitabb5590b297076f071b72f347d8d3204163e097b (patch)
treeb526d735f41a850977edce756f8f7c1020d35ccd /src/arch/x86/include
parentf9b3fae8d46a6b1862b3f5b02490e5a8c224286f (diff)
downloadipxe-abb5590b297076f071b72f347d8d3204163e097b.tar.gz
[pci] Replace pci_max_bus() with pci_num_bus()
Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/arch/x86/include')
-rw-r--r--src/arch/x86/include/ipxe/pcidirect.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/arch/x86/include/ipxe/pcidirect.h b/src/arch/x86/include/ipxe/pcidirect.h
index 4e933c43..7fa7c4fa 100644
--- a/src/arch/x86/include/ipxe/pcidirect.h
+++ b/src/arch/x86/include/ipxe/pcidirect.h
@@ -26,14 +26,14 @@ struct pci_device;
extern void pcidirect_prepare ( struct pci_device *pci, int where );
/**
- * Determine maximum PCI bus number within system
+ * Determine number of PCI buses within system
*
* @ret max_bus Maximum bus number
*/
static inline __always_inline int
-PCIAPI_INLINE ( direct, pci_max_bus ) ( void ) {
+PCIAPI_INLINE ( direct, pci_num_bus ) ( void ) {
/* No way to work this out via Type 1 accesses */
- return 0xff;
+ return 0x100;
}
/**
@@ -26,14 +26,14 @@ struct pci_device;
*
- * @ret max_bus Maximum bus number
+ * @ret num_bus Number of buses
*/
static inline __always_inline int